<?php

namespace Litecms\CouponOffer\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\CouponOffer\Http\Requests\CouponOfferRequest;
use Litecms\CouponOffer\Interfaces\CouponOfferRepositoryInterface;
use Litecms\CouponOffer\Models\CouponOffer;

/**
 * Resource controller class for coupon__offer.
 */
class CouponOfferResourceController extends BaseController
{

    /**
     * Initialize coupon__offer resource controller.
     *
     * @param type CouponOfferRepositoryInterface $coupon__offer
     *
     * @return null
     */
    public function __construct(CouponOfferRepositoryInterface $coupon__offer)
    {
        parent::__construct();
        $this->repository = $coupon__offer;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\CouponOffer\Repositories\Criteria\CouponOfferResourceCriteria::class);
    }

    /**
     * Display a list of coupon__offer.
     *
     * @return Response
     */
    public function index(CouponOfferRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\CouponOffer\Repositories\Presenter\CouponOfferPresenter::class)
                ->$function();
        }

        $coupon__offers = $this->repository->paginate();

        return $this->response->title(trans('coupon__offer::coupon__offer.names'))
            ->view('coupon__offer::coupon__offer.index', true)
            ->data(compact('coupon__offers'))
            ->output();
    }

    /**
     * Display coupon__offer.
     *
     * @param Request $request
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function show(CouponOfferRequest $request, CouponOffer $coupon__offer)
    {

        if ($coupon__offer->exists) {
            $view = 'coupon__offer::coupon__offer.show';
        } else {
            $view = 'coupon__offer::coupon__offer.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('coupon__offer::coupon__offer.name'))
            ->data(compact('coupon__offer'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new coupon__offer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CouponOfferRequest $request)
    {

        $coupon__offer = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('coupon__offer::coupon__offer.name')) 
            ->view('coupon__offer::coupon__offer.create', true) 
            ->data(compact('coupon__offer'))
            ->output();
    }

    /**
     * Create new coupon__offer.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CouponOfferRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $coupon__offer                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('coupon__offer::coupon__offer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('coupon__offer/coupon__offer/' . $coupon__offer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/coupon__offer/coupon__offer'))
                ->redirect();
        }

    }

    /**
     * Show coupon__offer for editing.
     *
     * @param Request $request
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function edit(CouponOfferRequest $request, CouponOffer $coupon__offer)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('coupon__offer::coupon__offer.name'))
            ->view('coupon__offer::coupon__offer.edit', true)
            ->data(compact('coupon__offer'))
            ->output();
    }

    /**
     * Update the coupon__offer.
     *
     * @param Request $request
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function update(CouponOfferRequest $request, CouponOffer $coupon__offer)
    {
        try {
            $attributes = $request->all();

            $coupon__offer->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('coupon__offer::coupon__offer.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('coupon__offer/coupon__offer/' . $coupon__offer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon__offer/coupon__offer/' . $coupon__offer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the coupon__offer.
     *
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function destroy(CouponOfferRequest $request, CouponOffer $coupon__offer)
    {
        try {

            $coupon__offer->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('coupon__offer::coupon__offer.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('coupon__offer/coupon__offer/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('coupon__offer/coupon__offer/' . $coupon__offer->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple coupon__offer.
     *
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function delete(CouponOfferRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('coupon__offer::coupon__offer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('coupon__offer/coupon__offer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/coupon__offer/coupon__offer'))
                ->redirect();
        }

    }

    /**
     * Restore deleted coupon__offers.
     *
     * @param Model   $coupon__offer
     *
     * @return Response
     */
    public function restore(CouponOfferRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('coupon__offer::coupon__offer.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/coupon__offer/coupon__offer'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/coupon__offer/coupon__offer/'))
                ->redirect();
        }

    }

}
